@@ -1,4 +1,5 @@
-from django.db import migrations, models
+from django.db import migrations
+from django.db import models
 
 
 class Migration(migrations.Migration):
@@ -11,9 +12,11 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.AlterModelTable(
-            name="attachment", table="wiki_attachments_attachment",
+            name="attachment",
+            table="wiki_attachments_attachment",
         ),
         migrations.AlterModelTable(
-            name="attachmentrevision", table="wiki_attachments_attachmentrevision",
+            name="attachmentrevision",
+            table="wiki_attachments_attachmentrevision",
         ),
     ]
